CREATE TABLE person (
	name	TEXT,
	email	TEXT,
	project	TEXT,
	nightplace	TEXT,
	night	INT2,
	infomail	INT2,
	insurance	INT2,
	list		INT2,
	admin	INT2 DEFAULT 0,
	login	INT2 DEFAULT 0,
	password	TEXT NOT NULL DEFAULT '',
	comment	TEXT
);

CREATE UNIQUE INDEX "person_name" on "person" using btree ( "name" );
CREATE INDEX "person_email" on "person" using btree ( "email" );
CREATE INDEX "person_project" on "person" using btree ( "project" );

REVOKE ALL on "person" from PUBLIC;
GRANT ALL on "person" to "www";
GRANT ALL on "person" to "joey";

-- INSERT INTO person VALUES ('Martin Schulze', 'joey@infodrom.north.de', 'Debian', '', 1, 1, 1,'');
-- INSERT INTO person VALUES ('Torsten Landschoff', 'torsten@debian.org', 'Debian', 'OeZ', 1, 1, 1,'');
-- INSERT INTO person VALUES ('Martin Baulig', 'baulig@gnome.org', 'Gnome', 'OeZ', 1, 1, 1,'');
-- INSERT INTO person VALUES ('Jens Finke', 'jens@gnome.org', 'Gnome', 'OeZ', 1, 0, 1,'');

CREATE TABLE project (
	name	TEXT,
	url	TEXT,
	boothnr	TEXT,
	boothsize	INT4,
	computer	INT4,
	comment	TEXT
);
CREATE UNIQUE INDEX "project_name" on "project" using btree ( "name" );

REVOKE ALL on "project" from PUBLIC;
GRANT ALL on "project" to "www";
GRANT ALL on "project" to "joey";

-- INSERT INTO project VALUES ('Debian','http://www.debian.org/', '','',0);
-- INSERT INTO project VALUES ('Gnome','http://www.gnome.org/', '','',0);

-- =======================================================================
CREATE TABLE comments (
	project TEXT,
	date datetime DEFAULT '1980-01-01 00:00' NOT NULL,
	who TEXT,
	email TEXT,
	body TEXT
);
CREATE INDEX "comments_project" on "comments" using btree ( "project" );

REVOKE ALL on "comments" from PUBLIC;
GRANT  ALL on "comments" to "www";
GRANT  ALL on "comments" to "joey";

-- =======================================================================

CREATE TABLE urls (
	project TEXT,
	url TEXT,
	description TEXT
);
CREATE INDEX "urls_project" on "urls" using btree ( "project" );

REVOKE ALL on "urls" from PUBLIC;
GRANT  ALL on "urls" to "www";
GRANT  ALL on "urls" to "joey";

-- INSERT INTO urls VALUES ('PHPGroupware', 'http://linux-at-work.de/', 'Deutsche PHPGroupware-Community');
-- INSERT INTO urls VALUES ('FlightGear', 'http://rockfish.net/fg/linuxworldnyc/boothcrew.jpg.', 'Booth at Linuxworld');
-- INSERT INTO urls VALUES ('FlightGear', 'http://flightgear.sourceforge.net/images/fglogosm.jpg.', 'Logo');

-- =======================================================================

CREATE TABLE appendix (
	project TEXT,
	boothtitle TEXT,
	description TEXT,
	description_en TEXT
);
CREATE INDEX "appendix_project" on "appendix" using btree ( "project" );

REVOKE ALL on "appendix" from PUBLIC;
GRANT  ALL on "appendix" to "www";
GRANT  ALL on "appendix" to "joey";

-- =======================================================================

CREATE TABLE todo (
	subject TEXT,
	who TEXT,
	email TEXT,
	date datetime DEFAULT '1980-01-01 00:00' NOT NULL,
        done datetime DEFAULT '1980-01-01 00:00',
	body TEXT
);
-- CREATE INDEX "todo" on "appendix" using btree ( "project" );

REVOKE ALL on "todo" from PUBLIC;
GRANT  ALL on "todo" to "www";
GRANT  ALL on "todo" to "joey";

-- =======================================================================

CREATE TABLE nili (
	person TEXT,
	date datetime DEFAULT '1980-01-01 00:00' NOT NULL,
	breakfast INT2,
	dinner INT2,
	sleeping INT2,
	comment TEXT
);

CREATE INDEX "nili_person" on "nili" using btree ( "person" );
CREATE INDEX "nili_date" on "nili" using btree ( "date" );

REVOKE ALL on "nili" from PUBLIC;
GRANT  ALL on "nili" to "www";
GRANT  ALL on "nili" to "joey";

-- INSERT INTO nili VALUES ('Andreas Fuchs','2001-07-04',0,1,1,'');
-- INSERT INTO nili VALUES ('Andreas Fuchs','2001-07-05',1,1,1,'');
-- INSERT INTO nili VALUES ('Andreas Fuchs','2001-07-06',1,0,0,'');
-- INSERT INTO nili VALUES ('Daniel Mester','2001-07-04',0,1,1,'');
-- INSERT INTO nili VALUES ('Daniel Mester','2001-07-05',1,1,1,'');
-- INSERT INTO nili VALUES ('Daniel Mester','2001-07-06',1,1,1,'');
-- INSERT INTO nili VALUES ('Daniel Mester','2001-07-07',1,0,0,'');
-- INSERT INTO nili VALUES ('Oliver Bolzer','2001-07-04',0,1,1,'');
-- INSERT INTO nili VALUES ('Oliver Bolzer','2001-07-05',1,0,1,'');
-- INSERT INTO nili VALUES ('Oliver Bolzer','2001-07-06',1,0,1,'');
-- INSERT INTO nili VALUES ('Oliver Bolzer','2001-07-07',1,0,0,'');

-- =======================================================================

CREATE TABLE workshop (
	title TEXT NOT NULL DEFAULT '',
	speaker TEXT NOT NULL DEFAULT '',
	date_time datetime DEFAULT '1980-01-01 00:00' NOT NULL,
	room TEXT NOT NULL DEFAULT '',
	project TEXT NOT NULL DEFAULT '',
	abstract TEXT,
	visible INT2,
	comment TEXT
);

CREATE INDEX "workshop_date" on "workshop" using btree ( "date_time" );

REVOKE ALL on "workshop" from PUBLIC;
GRANT  ALL on "workshop" to "www";
GRANT  ALL on "workshop" to "joey";

-- =======================================================================

CREATE TABLE supplylist (
        id TEXT NOT NULL DEFAULT '',
	name TEXT NOT NULL DEFAULT '',
	height INT,
	width INT,
	depth INT,
	img_src TEXT,
	img_height INT,
	img_width INT,
	price float4,
	visible INT2,
	comment TEXT
);

CREATE UNIQUE INDEX "supplylist_id" on "supplylist" using btree ( "id" );
CREATE INDEX "supplylist_name" on "supplylist" using btree ( "name" );

REVOKE ALL on "supplylist" from PUBLIC;
GRANT  ALL on "supplylist" to "www";
GRANT  ALL on "supplylist" to "joey";

-- =======================================================================

CREATE TABLE supplies (
	supply TEXT NOT NULL DEFAULT '',
	project TEXT NOT NULL DEFAULT '',
	amount INT,
	comment TEXT
);

CREATE INDEX "supplies_supply"  on "supplies" using btree ( "supply" );
CREATE INDEX "supplies_project" on "supplies" using btree ( "project" );

REVOKE ALL on "supplies" from PUBLIC;
GRANT  ALL on "supplies" to "www";
GRANT  ALL on "supplies" to "joey";

